SWDEV-339113 - Update sampl codes with correct kernel coordinate (#2704)

Change-Id: Ibfc0fd285441cd3d79b312d2b739729a039a6f84

[ROCm/hip-tests commit: 5da168300f]
This commit is contained in:
ROCm CI Service Account
2022-06-02 17:07:52 +05:30
کامیت شده توسط GitHub
والد f35a48c8fb
کامیت eddb025028
14فایلهای تغییر یافته به همراه47 افزوده شده و 47 حذف شده
@@ -23,6 +23,6 @@ THE SOFTWARE.
#include "hip/hip_runtime.h"
extern "C" __global__ void hello_world(float* a, float* b) {
int tx = hipThreadIdx_x;
int tx = threadIdx.x;
b[tx] = a[tx];
}